package com.link.common.utils;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.sql.Struct;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.link.modules.job.service.ScheduleJobLogService;
import com.link.modules.sys.service.SysParamsService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.annotation.Resource;

/**
 * @author Shaun
 */
public class WxUtils {
    private static final String CORP_ID = "CORP_ID";
    private static final String SECRET = "SECRET";
    private static final Logger LOGGER = LoggerFactory.getLogger(WxUtils.class);
    private static String accessToken = null;
    private static Date lastGetTokenTime = null;
    /**
     * 企业微信accessToken的失效时间，单位秒，默认2小时
     */
    private static final int EXPIRE_SECONDS = 7200;

    private static SysParamsService sysParamsService;


    public static String getAccessToken() {
        Date now = new Date();
        if (sysParamsService == null) {
            sysParamsService = SpringContextUtils.getBean(SysParamsService.class);
        }
        if (accessToken == null || lastGetTokenTime == null || DateUtils.addDateSeconds(lastGetTokenTime,
                EXPIRE_SECONDS).compareTo(now) > 0) {
            //根据参数管理中的值获取企业ID和CRM应用Secret
            String corpId = sysParamsService.getValue(CORP_ID);
            String secret = sysParamsService.getValue(SECRET);
            if (StrUtil.isBlank(corpId) || StrUtil.isBlank(secret)) {
                LOGGER.info("cannot find corpId {} or secret {}", corpId, secret);
                return accessToken;
            }
            String getTokenUrl = "https://qyapi.weixin.qq.com/cgi-bin/gettoken?corpid=" + corpId + "&corpsecret=" + secret;
            try {
                accessToken = HttpUtil.get(getTokenUrl);
                Map<String, Object> map = JSONObject.parseObject(accessToken);
                accessToken = map.get("access_token").toString();
                lastGetTokenTime = now;
                LOGGER.info("{} 获取Token：{}", now, accessToken);
            } catch (Exception e) {
                LOGGER.error("failed to get token", e);
            }
        }
        return accessToken;
    }

}
