/**
 * Copyright (c) 2018 开源 All rights reserved.
 * <p>
 * https://www.link.io
 * <p>
 * 版权所有，侵权必究！
 */

package com.link.controller;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.convert.Convert;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUnit;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.lang.Editor;
import cn.hutool.core.map.MapUtil;
import cn.hutool.core.util.ArrayUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.PropertyFilter;
import com.alibaba.fastjson.serializer.SimplePropertyPreFilter;
import com.link.annotation.Login;
import com.link.annotation.LoginUser;
import com.link.common.constant.Constant;
import com.link.common.exception.RenException;
import com.link.common.page.PageData;
import com.link.common.utils.Result;
import com.link.dto.AgentnodeDTO;
import com.link.dto.BdajobConfigDTO;
import com.link.dto.BdajobDTO;
import com.link.dto.IndiceDTO;
import com.link.dto.IndiceDataDTO;
import com.link.dto.OoziejobresultDTO;
import com.link.entity.UserEntity;
import com.link.service.AgentnodeService;
import com.link.service.BdajobConfigService;
import com.link.service.BdajobService;
import com.link.service.IndiceDataService;
import com.link.service.IndiceService;
import com.link.service.OoziejobresultService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import springfox.documentation.annotations.ApiIgnore;

import java.text.DateFormat;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * 测试接口
 *
 * @author Mark sunlightcs@gmail.com
 */
@RestController
@RequestMapping("/api")
@Api(tags = "数据接口")
public class ApiController {

    @Autowired
    private AgentnodeService agentnodeService;
    @Autowired
    private BdajobService bdajobService;
    @Autowired
    private OoziejobresultService ooziejobresultService;
    @Autowired
    private BdajobConfigService bdajobConfigService;
    @Autowired
    private IndiceService indiceService;
    @Autowired
    private IndiceDataService indiceDataService;

    @Login
    @GetMapping("getAgentnode")
    @ApiOperation("获取节点")
    @ApiImplicitParams({
            @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", dataType = "int"),
            @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query", dataType = "int"),
            @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = "name", value = "节点名称", paramType = "query", dataType = "String")
    })
    public Result<PageData<AgentnodeDTO>> getAgentnode(@ApiIgnore @RequestParam Map<String, Object> params) {
        PageData<AgentnodeDTO> page = agentnodeService.page(params);
        return new Result<PageData<AgentnodeDTO>>().ok(page);
    }

    @Login
    @GetMapping("getBdajob")
    @ApiOperation("获取应用")
    @ApiImplicitParams({
            @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", dataType = "int"),
            @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query", dataType = "int"),
            @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = "jobName", value = "应用名称", paramType = "query", dataType = "String")
    })
    public Result<PageData<BdajobDTO>> getBdajob(@ApiIgnore @RequestParam Map<String, Object> params) {
        PageData<BdajobDTO> page = bdajobService.page(params);
        Map<String, Object> paramsMap = new HashMap<>();
        for (BdajobDTO bdajobDto : page.getList()) {
            paramsMap.clear();
            paramsMap.put("jobId", bdajobDto.getJobId());
            List<BdajobConfigDTO> bdajobConfigDtoList = bdajobConfigService.list(paramsMap);
            bdajobDto.setBdajobConfigDtoList(bdajobConfigDtoList);
        }
        return new Result<PageData<BdajobDTO>>().ok(page);
    }

/*
    @Login
    @GetMapping("getBdajobConfig")
    @ApiOperation("获取指标")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "fieldType", value = "指标类型（0-草稿，1-正式）", paramType = "query", dataType = "String")
    })
    public Result<PageData<BdajobConfigDTO>> getBdajobConfig(@ApiIgnore @RequestParam Map<String, Object> params) {
        PageData<BdajobConfigDTO> page = bdajobConfigService.page(params);

        return new Result<PageData<BdajobConfigDTO>>().ok(page);
    }

    @Login
    @GetMapping("getBusinessIndiceByCycle")
    @ApiOperation("获取结果")
    @ApiImplicitParams({
            */
/*@ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", dataType = "int"),
            @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query", dataType = "int"),
            @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType = "String"),*//*

            @ApiImplicitParam(name = "node", value = "下沉节点编码，如果多个，须以“,”隔开，如果为空，则默认获取所有节点指标数据，下沉节点编码参见附件《各省下沉计算节点代码表》", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = "type", value = "周期类型：1-年，2-季度，3-月度，4-周，5-日，6-小时", paramType = "query", dataType = "int", required = true),
            @ApiImplicitParam(name = "cycle", value = "周期值，根据周期类型，周期值格式也不同，具体要求如下：" +
                    "① 年，4位年度值，如2020；" +
                    "② 季度，4位年度值+2位季度序号（01-04），如202001；" +
                    "③ 月度，4位年度值+2位月度值（01-12），如202001；" +
                    "④ 周，4位年度值+2位周序号（01-52），如202016；" +
                    "⑤ 日，4位年度值+2位月度值+2位日数值，如20200101；" +
                    "⑥ 小时，4位年度值+2位月度值+2位日数值+2位小时数，如2020010112", paramType = "query", dataType = "String", required = true),
            @ApiImplicitParam(name = "indice", value = "指标编码，如果有多个指标，须以“,”隔开，下沉计算项目组将定期发布《下沉计算指标编码表》", paramType = "query", dataType = "String", required = true)
    })
    public Result<Map<String, Object>> getOoziejobresult(@ApiIgnore @RequestParam Map<String, Object> params) {

        Integer type = Convert.toInt(params.get("type"));
        if (type == null) {
            throw new RenException("周期类型不能为空");
        }
        String cycle = Convert.toStr(params.get("cycle"));
        if (StrUtil.isBlank(cycle)) {
            throw new RenException("周期值不能为空");
        }
        String indice = Convert.toStr(params.get("indice"));
        if (StrUtil.isBlank(indice)) {
            throw new RenException("指标不能为空");
        }

        //处理时间
        Date beginTime = null;
        Date endTime = null;
        if (Objects.equals(type, 1)) {
            DateTime date = DateUtil.parse(cycle, "yyyy");
            beginTime = DateUtil.beginOfYear(date);
            endTime = DateUtil.endOfYear(date);
        } else if (Objects.equals(type, 2)) {
            if (StrUtil.length(cycle) >= 6) {
                DateTime dateTime = DateUtil.parse(StrUtil.sub(cycle, 0, 4), "yyyy");
                Integer quarter = Convert.toInt(StrUtil.sub(cycle, 4, 6));
                if (dateTime != null && quarter != null) {
                    DateTime date = DateUtil.offsetMonth(dateTime, 3 * (quarter - 1));
                    beginTime = DateUtil.beginOfQuarter(date);
                    endTime = DateUtil.endOfQuarter(date);
                }
            }
        } else if (Objects.equals(type, 3)) {
            DateTime date = DateUtil.parse(cycle, "yyyyMM");
            beginTime = DateUtil.beginOfMonth(date);
            endTime = DateUtil.endOfMonth(date);
        } else if (Objects.equals(type, 4)) {
            if (StrUtil.length(cycle) >= 6) {
                DateTime dateTime = DateUtil.parse(StrUtil.sub(cycle, 0, 4), "yyyy");
                Integer week = Convert.toInt(StrUtil.sub(cycle, 4, 6));
                if (dateTime != null && week != null) {
                    DateTime date = DateUtil.offsetWeek(dateTime, week - 1);
                    beginTime = DateUtil.beginOfWeek(date);
                    endTime = DateUtil.endOfWeek(date);
                }
            }
        } else if (Objects.equals(type, 5)) {
            DateTime date = DateUtil.parse(cycle, "yyyyMMdd");
            beginTime = DateUtil.beginOfDay(date);
            endTime = DateUtil.endOfDay(date);
        } else if (Objects.equals(type, 6)) {
            DateTime date = DateUtil.parse(cycle, "yyyyMMddHH");
            beginTime = date;
            endTime = DateUtil.offsetSecond(DateUtil.offsetHour(date, 1), -1);
        }

        if (beginTime == null || endTime == null) {
            throw new RenException("时间解析失败");
        }


        Map<String, Object> paramsMap = new HashMap<>();

        //获取所有节点
        paramsMap.clear();
        paramsMap.put("nodeIds", Convert.toStr(params.get("node")));
        List<AgentnodeDTO> agentnodeDtoList = agentnodeService.list(paramsMap);

        //根据指标获取应用id
        paramsMap.clear();
        String[] indiceArr = StrUtil.split(indice, ",");
        paramsMap.put("fieldCodeArr", indiceArr);
        List<BdajobConfigDTO> bdajobConfigDtoList = bdajobConfigService.list(paramsMap);
        MultiValueMap<String, BdajobConfigDTO> jobIdMap = new LinkedMultiValueMap<>();
        for (BdajobConfigDTO bdajobConfigDto : bdajobConfigDtoList) {
            jobIdMap.add(bdajobConfigDto.getJobId(), bdajobConfigDto);
        }


        //获取结果
        paramsMap.clear();
        paramsMap.put("nodeIds", Convert.toStr(params.get("node")));
        paramsMap.put("jobIdList", jobIdMap.keySet());
        paramsMap.put("beginTime", DateUtil.format(beginTime, "yyyy-MM-dd HH:mm:ss"));
        paramsMap.put("endTime", DateUtil.format(endTime, "yyyy-MM-dd HH:mm:ss"));
        paramsMap.put("orderBy", "t.createdTime asc");
        List<OoziejobresultDTO> list = ooziejobresultService.getJoinList(paramsMap);

        //按格式封装数据
        Map<String, Object> resultMap = new HashMap<>();
        LinkedHashMap<String, LinkedHashMap<String, ArrayList<Object>>> resultLinkedHashMap = new LinkedHashMap<>();
        resultMap.put("type", params.get("type"));
        resultMap.put("cycle", params.get("cycle"));
        resultMap.put("total", indiceArr.length);

        for (OoziejobresultDTO ooziejobresultDto : list) {
            List<BdajobConfigDTO> indiceList = jobIdMap.get(ooziejobresultDto.getJobId());
            if (CollUtil.isNotEmpty(indiceList)) {


                String result = ooziejobresultDto.getResult();
                if (StrUtil.isNotBlank(result)) {
                    if (JSON.isValid(result)) {
                        if (JSON.isValidObject(result)) {
                            JSONObject jsonObject = JSON.parseObject(result);
                            for (BdajobConfigDTO bdajobConfigDto : indiceList) {
                                LinkedHashMap<String, ArrayList<Object>> stringArrayListLinkedHashMap = resultLinkedHashMap.get(bdajobConfigDto.getFieldCode());
                                if (stringArrayListLinkedHashMap == null) {
                                    stringArrayListLinkedHashMap = new LinkedHashMap<>();
                                    resultLinkedHashMap.put(bdajobConfigDto.getFieldCode(), stringArrayListLinkedHashMap);
                                }
                                for (AgentnodeDTO agentnodeDto : agentnodeDtoList) {
                                    ArrayList<Object> objects = stringArrayListLinkedHashMap.get(agentnodeDto.getId());
                                    if (objects == null) {
                                        objects = new ArrayList<>();
                                        stringArrayListLinkedHashMap.put(Convert.toStr(ooziejobresultDto.getNodeid()), objects);
                                    }
                                    objects.add(jsonObject.get(bdajobConfigDto.getFieldName()));
                                }
                            }
                        } else {
                            JSONArray jsonArray = JSON.parseArray(result);

                            for (BdajobConfigDTO bdajobConfigDto : indiceList) {
                                LinkedHashMap<String, ArrayList<Object>> stringArrayListLinkedHashMap = resultLinkedHashMap.get(bdajobConfigDto.getFieldCode());
                                if (stringArrayListLinkedHashMap == null) {
                                    stringArrayListLinkedHashMap = new LinkedHashMap<>();
                                    resultLinkedHashMap.put(bdajobConfigDto.getFieldCode(), stringArrayListLinkedHashMap);
                                }

                                List<Object> jsonArrayList = new ArrayList<>();
                                if (CollUtil.isNotEmpty(jsonArray)) {
                                    //只过滤第一层
                                    for (Object o : jsonArray) {
                                        if (o instanceof JSONObject) {
                                            jsonArrayList.add(((JSONObject) o).get(bdajobConfigDto.getFieldName()));
                                        } else {
                                            jsonArrayList.add(o);
                                        }
                                    }
                                }
                                for (AgentnodeDTO agentnodeDto : agentnodeDtoList) {
                                    ArrayList<Object> objects = stringArrayListLinkedHashMap.get(agentnodeDto.getId());
                                    if (objects == null) {
                                        objects = new ArrayList<>();
                                        stringArrayListLinkedHashMap.put(Convert.toStr(ooziejobresultDto.getNodeid()), objects);
                                    }
                                    objects.add(jsonArrayList);
                                }

                            }
                        }
                    }
                }
            }
        }

        List<Object> firstList = new ArrayList<>();
        for (String indiceItem : indiceArr) {
            Map<String, Object> firstMap = new LinkedHashMap<>();
            firstList.add(firstMap);
            firstMap.put("indice", indiceItem);
            firstMap.put("total", agentnodeDtoList.size());
            LinkedHashMap<String, ArrayList<Object>> stringArrayListLinkedHashMap = resultLinkedHashMap.get(indiceItem);
            List<Object> secondList = new ArrayList<>();
            firstMap.put("list", secondList);
            for (AgentnodeDTO agentnodeDto : agentnodeDtoList) {
                Map<String, Object> secondMap = new LinkedHashMap<>();
                secondMap.put("node", agentnodeDto.getId());
                secondMap.put("value", stringArrayListLinkedHashMap == null ? new ArrayList<>() : stringArrayListLinkedHashMap.get(Convert.toStr(agentnodeDto.getId())));
                secondList.add(secondMap);
            }
        }

        resultMap.put("list", firstList);

        return new Result<Map<String, Object>>().ok(resultMap);
    }
*/

    @Login
    @GetMapping("getBdajobConfig")
    @ApiOperation("获取指标")
    @ApiImplicitParams({
            @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", dataType = "int"),
            @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query", dataType = "int"),
            @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = "indice", value = "指标编码", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = "indiceName", value = "指标名称", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = "indiceDesc", value = "指标描述", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = "type", value = "指标类型", paramType = "query", dataType = "String")
    })
    public Result<PageData<IndiceDTO>> getBdajobConfig(@ApiIgnore @RequestParam Map<String, Object> params) {
        params = MapUtil.filter(params, new Editor<Map.Entry<String, Object>>() {
            @Override
            public Map.Entry<String, Object> edit(Map.Entry<String, Object> stringObjectEntry) {
                if(Objects.equals(stringObjectEntry.getValue(),"null")){
                    return null;
                }else{
                    return stringObjectEntry;
                }
            }
        });
        PageData<IndiceDTO> page = indiceService.page(params);

        return new Result<PageData<IndiceDTO>>().ok(page);
    }

    @Login
    @GetMapping("getBusinessIndiceByCycle")
    @ApiOperation("获取结果")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "node", value = "下沉节点编码，如果多个，须以“,”隔开，如果为空，则默认获取所有节点指标数据，下沉节点编码参见附件《各省下沉计算节点代码表》", paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = "type", value = "周期类型：1-年，2-季度，3-月度，4-周，5-日，6-小时", paramType = "query", dataType = "int", required = true),
            @ApiImplicitParam(name = "cycle", value = "周期值，根据周期类型，周期值格式也不同，具体要求如下：" +
                    "① 年，4位年度值，如2020；" +
                    "② 季度，4位年度值+2位季度序号（01-04），如202001；" +
                    "③ 月度，4位年度值+2位月度值（01-12），如202001；" +
                    "④ 周，4位年度值+2位周序号（01-52），如202016；" +
                    "⑤ 日，4位年度值+2位月度值+2位日数值，如20200101；" +
                    "⑥ 小时，4位年度值+2位月度值+2位日数值+2位小时数，如2020010112", paramType = "query", dataType = "String", required = true),
            @ApiImplicitParam(name = "indice", value = "指标编码，如果有多个指标，须以“,”隔开，下沉计算项目组将定期发布《下沉计算指标编码表》", paramType = "query", dataType = "String", required = true)
    })
    public Result<Map<String, Object>> getOoziejobresult(@ApiIgnore @RequestParam Map<String, Object> params) {
        params = MapUtil.filter(params, new Editor<Map.Entry<String, Object>>() {
            @Override
            public Map.Entry<String, Object> edit(Map.Entry<String, Object> stringObjectEntry) {
                if(Objects.equals(stringObjectEntry.getValue(),"null")){
                    return null;
                }else{
                    return stringObjectEntry;
                }
            }
        });

        Integer type = Convert.toInt(params.get("type"));
        if (type == null) {
            throw new RenException("周期类型不能为空");
        }
        String cycle = Convert.toStr(params.get("cycle"));
        if (StrUtil.isBlank(cycle)) {
            throw new RenException("周期值不能为空");
        }
        String indice = Convert.toStr(params.get("indice"));
        if (StrUtil.isBlank(indice)) {
            throw new RenException("指标不能为空");
        }

        //处理时间
        Date beginTime = null;
        Date endTime = null;
        if (Objects.equals(type, 1)) {
            DateTime date = DateUtil.parse(cycle, "yyyy");
            beginTime = DateUtil.beginOfYear(date);
            endTime = DateUtil.endOfYear(date);
        } else if (Objects.equals(type, 2)) {
            if (StrUtil.length(cycle) >= 6) {
                DateTime dateTime = DateUtil.parse(StrUtil.sub(cycle, 0, 4), "yyyy");
                Integer quarter = Convert.toInt(StrUtil.sub(cycle, 4, 6));
                if (dateTime != null && quarter != null) {
                    DateTime date = DateUtil.offsetMonth(dateTime, 3 * (quarter - 1));
                    beginTime = DateUtil.beginOfQuarter(date);
                    endTime = DateUtil.endOfQuarter(date);
                }
            }
        } else if (Objects.equals(type, 3)) {
            DateTime date = DateUtil.parse(cycle, "yyyyMM");
            beginTime = DateUtil.beginOfMonth(date);
            endTime = DateUtil.endOfMonth(date);
        } else if (Objects.equals(type, 4)) {
            if (StrUtil.length(cycle) >= 6) {
                DateTime dateTime = DateUtil.parse(StrUtil.sub(cycle, 0, 4), "yyyy");
                Integer week = Convert.toInt(StrUtil.sub(cycle, 4, 6));
                if (dateTime != null && week != null) {
                    DateTime date = DateUtil.offsetWeek(dateTime, week - 1);
                    beginTime = DateUtil.beginOfWeek(date);
                    endTime = DateUtil.endOfWeek(date);
                }
            }
        } else if (Objects.equals(type, 5)) {
            DateTime date = DateUtil.parse(cycle, "yyyyMMdd");
            beginTime = DateUtil.beginOfDay(date);
            endTime = DateUtil.endOfDay(date);
        } else if (Objects.equals(type, 6)) {
            DateTime date = DateUtil.parse(cycle, "yyyyMMddHH");
            beginTime = date;
            endTime = DateUtil.offsetSecond(DateUtil.offsetHour(date, 1), -1);
        }

        if (beginTime == null || endTime == null) {
            throw new RenException("时间解析失败");
        }


        Map<String, Object> paramsMap = new HashMap<>();

        //获取所有节点
        paramsMap.clear();
        paramsMap.put("nodeIds", Convert.toStr(params.get("node")));
        List<AgentnodeDTO> agentnodeDtoList = agentnodeService.list(paramsMap);

        //根据指标编码获取指标
        paramsMap.clear();
        paramsMap.put("indices", Convert.toStr(params.get("indice")));
        List<IndiceDTO> indiceDTOList = indiceService.list(paramsMap);


        //获取结果
        paramsMap.clear();
        paramsMap.put("nodeIds", Convert.toStr(params.get("node")));
        paramsMap.put("indiceIds", StrUtil.join(",",indiceDTOList.stream().map(IndiceDTO::getId).collect(Collectors.toList())));
        paramsMap.put("beginTime", DateUtil.format(beginTime, "yyyy-MM-dd HH:mm:ss"));
        paramsMap.put("endTime", DateUtil.format(endTime, "yyyy-MM-dd HH:mm:ss"));
        paramsMap.put("orderBy", "t.create_time asc");
        List<IndiceDataDTO> indiceDataDTOList =indiceDataService.getJoinList(paramsMap);

        LinkedHashMap<String, LinkedHashMap<String, ArrayList<Object>>> resultLinkedHashMap = new LinkedHashMap<>();
        for(IndiceDataDTO indiceDataDTO:indiceDataDTOList){
            LinkedHashMap<String, ArrayList<Object>> stringArrayListLinkedHashMap = resultLinkedHashMap.get(Convert.toStr(indiceDataDTO.getIndiceId()));
            if(stringArrayListLinkedHashMap == null){
                stringArrayListLinkedHashMap = new LinkedHashMap<>();
                resultLinkedHashMap.put(Convert.toStr(indiceDataDTO.getIndiceId()),stringArrayListLinkedHashMap);
            }
            ArrayList<Object> objects = stringArrayListLinkedHashMap.get(Convert.toStr(indiceDataDTO.getNodeId()));
            if(objects == null){
                objects = new ArrayList<>();
                stringArrayListLinkedHashMap.put(Convert.toStr(indiceDataDTO.getNodeId()),objects);
            }
            objects.add(indiceDataDTO.getResultData());
        }

        //按格式封装数据
        Map<String, Object> resultMap = new HashMap<>();
        resultMap.put("type", params.get("type"));
        resultMap.put("cycle", params.get("cycle"));
        resultMap.put("total", indiceDTOList.size());
        List<Object> indiceList = new ArrayList<>();
        resultMap.put("list", indiceList);
        for(IndiceDTO indiceDTO:indiceDTOList){
            Map<String,Object> indiceMap = new HashMap<>();
            indiceList.add(indiceMap);
            indiceMap.put("indice",indiceDTO.getIndice());
            indiceMap.put("total",agentnodeDtoList.size());
            List<Map<String,Object>> nodeList = new ArrayList<>();
            indiceMap.put("list",nodeList);
            LinkedHashMap<String, ArrayList<Object>> stringArrayListLinkedHashMap = resultLinkedHashMap.get(Convert.toStr(indiceDTO.getId()));
            for(AgentnodeDTO agentnodeDTO:agentnodeDtoList){
                Map<String,Object> nodeMap = new HashMap<>();
                nodeMap.put("node",agentnodeDTO.getId());
                if(MapUtil.isNotEmpty(stringArrayListLinkedHashMap) && CollUtil.isNotEmpty(stringArrayListLinkedHashMap.get(Convert.toStr(agentnodeDTO.getId())))){
                    nodeMap.put("value",stringArrayListLinkedHashMap.get(Convert.toStr(agentnodeDTO.getId())));
                }else{
                    nodeMap.put("value",new ArrayList<>());
                }
                nodeList.add(nodeMap);
            }
        }

        return new Result<Map<String, Object>>().ok(resultMap);
    }

}